# timer.py
import time
import utils


class TimerError(Exception):
    """A custom exception used to report errors in use of Timer class"""


class Timer:

    def __init__(self, timer_name):
        self._start_time = None
        self._set_timer_name(timer_name)

    def start(self):
        """Start a new timer"""

        if self._start_time is not None:
            raise TimerError(f"Timer is running. Use .stop() to stop it")
        self._start_time = time.perf_counter()

    def stop(self):
        """Stop the timer, and report the elapsed time"""

        if self._start_time is None:
            raise TimerError(f"Timer is not running. Use .start() to start it")

        elapsed_time = time.perf_counter() - self._start_time
        self._start_time = None
        self.logger.info(f"Elapsed time: {elapsed_time:0.6f} seconds")

    def _set_timer_name(self, timer_name):
        self.timer_name = timer_name
        self.logger = utils.get_logger(timer_name)

